@@ -9,6 +9,10 @@ from typing import Iterable, Union
 PRECISION: float = 1e-2
 DECIMAL_PLACES: int = int(-log10(PRECISION))
 
+DATACLASS_KWARGS = {"frozen": True}
+if sys.version_info >= (3, 10):
+    DATACLASS_KWARGS["slots"] = True
+
 
 def ensure_precision(number: float) -> float:
     return round(number, DECIMAL_PLACES)
@@ -19,11 +23,6 @@ def epoch() -> float:
     return ensure_precision(time.time())
 
 
-DATACLASS_KWARGS = {"frozen": True}
-if sys.version_info >= (3, 10):
-    DATACLASS_KWARGS["slots"] = True
-
-
 @dataclass(**DATACLASS_KWARGS)
 class Hit:
     key: str = field(
@@ -54,14 +53,22 @@ class Rate:
     :return: a Rate object
     """
 
-    hits: int = 2000
-    interval: float = 1
+    hits: int
+    interval: float
 
     @property
     def ratio(self) -> float:
         """Return the rate as float in hits/seconds units."""
         return max(self.hits, 0) / max(self.interval, PRECISION)
 
+    @classmethod
+    def __assert_class(cls, other) -> "Rate":
+        if not isinstance(other, Rate):
+            raise TypeError(
+                f"Can't compare {cls.__name__} with {other.__class__.__name__}"
+            )
+        return other
+
     def __lt__(self, other: Union["Rate", int, float]) -> bool:
         if isinstance(other, (int, float)):
             return self.ratio < other
@@ -72,16 +79,17 @@ class Rate:
             return self.ratio > other
         return self.ratio > other.ratio
 
-    def __eq__(self, other: Union["Rate", int, float]) -> bool:
+    def __eq__(self, other) -> bool:
         if isinstance(other, (int, float)):
             return self.ratio == other
+        other = self.__assert_class(other)
         return self.ratio == other.ratio
 
     @classmethod
-    def create_from_hits(cls, hits: Iterable[Hit]) -> "Rate":
+    def from_hits(cls, hits: Iterable[Hit]) -> "Rate":
         it1, it2, it3 = itertools.tee(hits, 3)
-        hits = reduce(lambda a, b: a + b.cost, it1, 0)
+        cost: int = reduce(lambda a, b: a + b.cost, it1, 0)
         return cls(
-            hits=hits,
-            interval=ensure_precision(max(it2).time - min(it3).time) if hits > 0 else 0,
+            hits=cost,
+            interval=ensure_precision(max(it2).time - min(it3).time) if cost > 0 else 0,
         )
